@@ -1,3 +1,4 @@
+"""An extension application."""
 import logging
 import re
 import sys
@@ -16,7 +17,6 @@ from jupyter_server.utils import is_namespace_package, url_path_join
 
 from .handler import ExtensionHandlerMixin
 
-
 # -----------------------------------------------------------------------------
 # Util functions and classes.
 # -----------------------------------------------------------------------------
@@ -88,7 +88,7 @@ class ExtensionAppJinjaMixin(HasTraits):
 
     @t.no_type_check
     def _prepare_templates(self):
-        # Get templates defined in a subclass.
+        """Get templates defined in a subclass."""
         self.initialize_templates()
         # Add templates to web app settings if extension has templates.
         if len(self.template_paths) > 0:
@@ -124,12 +124,14 @@ class ExtensionApp(JupyterApp):
     """Base class for configurable Jupyter Server Extension Applications.
 
     ExtensionApp subclasses can be initialized two ways:
-    1. Extension is listed as a jpserver_extension, and ServerApp calls
-        its load_jupyter_server_extension classmethod. This is the
-        classic way of loading a server extension.
-    2. Extension is launched directly by calling its `launch_instance`
-        class method. This method can be set as a entry_point in
-        the extensions setup.py
+
+    - Extension is listed as a jpserver_extension, and ServerApp calls
+      its load_jupyter_server_extension classmethod. This is the
+      classic way of loading a server extension.
+
+    - Extension is launched directly by calling its `launch_instance`
+      class method. This method can be set as a entry_point in
+      the extensions setup.py.
     """
 
     # Subclasses should override this trait. Tells the server if
@@ -172,6 +174,7 @@ class ExtensionApp(JupyterApp):
 
     @classmethod
     def get_extension_package(cls):
+        """Get an extension package."""
         parts = cls.__module__.split(".")
         if is_namespace_package(parts[0]):
             # in this case the package name is `<namespace>.<package>`.
@@ -180,6 +183,7 @@ class ExtensionApp(JupyterApp):
 
     @classmethod
     def get_extension_point(cls):
+        """Get an extension point."""
         return cls.__module__
 
     # Extension URL sets the default landing page for this extension.
@@ -210,7 +214,7 @@ class ExtensionApp(JupyterApp):
         if ServerApp.initialized():
             try:
                 return ServerApp.instance()
-            except Exception:
+            except Exception:  # noqa
                 # error retrieving instance, e.g. MultipleInstanceError
                 pass
 
@@ -289,6 +293,7 @@ class ExtensionApp(JupyterApp):
         self.settings[f"{self.name}_config"] = self.extension_config
 
     def _prepare_settings(self):
+        """Prepare the settings."""
         # Make webapp settings accessible to initialize_settings method
         webapp = self.serverapp.web_app
         self.settings.update(**webapp.settings)
@@ -308,6 +313,7 @@ class ExtensionApp(JupyterApp):
         webapp.settings.update(**self.settings)
 
     def _prepare_handlers(self):
+        """Prepare the handlers."""
         webapp = self.serverapp.web_app
 
         # Get handlers defined by extension subclass.
@@ -349,12 +355,13 @@ class ExtensionApp(JupyterApp):
         webapp.add_handlers(".*$", new_handlers)
 
     def _prepare_templates(self):
-        # Add templates to web app settings if extension has templates.
+        """Add templates to web app settings if extension has templates."""
         if len(self.template_paths) > 0:
             self.settings.update({f"{self.name}_template_paths": self.template_paths})
         self.initialize_templates()
 
     def _jupyter_server_config(self):
+        """The jupyter server config."""
         base_config = {
             "ServerApp": {
                 "default_url": self.default_url,
@@ -404,11 +411,10 @@ class ExtensionApp(JupyterApp):
         corresponding server app and webapp should already
         be initialized by this step.
 
-        1) Appends Handlers to the ServerApp,
-        2) Passes config and settings from ExtensionApp
-        to the Tornado web application
-        3) Points Tornado Webapp to templates and
-        static assets.
+        - Appends Handlers to the ServerApp,
+        - Passes config and settings from ExtensionApp
+          to the Tornado web application
+        - Points Tornado Webapp to templates and static assets.
         """
         if not self.serverapp:
             msg = (
@@ -582,7 +588,7 @@ class ExtensionApp(JupyterApp):
         extension's landing page.
         """
         # Handle arguments.
-        if argv is None:
+        if argv is None:  # noqa
             args = sys.argv[1:]  # slice out extension config.
         else:
             args = argv
